#[non_exhaustive]#[repr(i32)]pub enum QueryEndReason {
Unspecified = 0,
ItemLimit = 1,
ScanLimit = 2,
CheckpointBound = 3,
CursorBound = 4,
LedgerTip = 5,
}unstable only.Expand description
Reason the server stopped this query response.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified = 0
The stop reason was not specified.
ItemLimit = 1
The response reached the requested item limit. Resume from the last
Watermark.cursor received to continue reading the same effective
interval.
ScanLimit = 2
The response reached the server’s per-request bucket-fetch budget for
filtered scans before reaching the effective interval bound. Resume from
the last Watermark.cursor received.
CheckpointBound = 3
The scan reached a requested checkpoint range bound.
CursorBound = 4
The scan reached an exclusive cursor bound.
LedgerTip = 5
The scan reached the currently indexed ledger tip.
Implementations
Sourceimpl QueryEndReason
impl QueryEndReason
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.