#[non_exhaustive]pub struct CheckpointItem {
pub checkpoint: Option<Checkpoint>,
pub watermark: Option<Watermark>,
}unstable only.Expand description
One checkpoint item.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.checkpoint: Option<Checkpoint>One matching checkpoint.
watermark: Option<Watermark>Progress watermark as of when this item was emitted: its cursor
is the resume point past this item, and checkpoint_hi /
checkpoint_lo (whichever matches the request ordering) is the
inclusive boundary checkpoint that the scan has fully covered.
Implementations
Sourceimpl CheckpointItem
impl CheckpointItem
pub const CHECKPOINT_FIELD: &'static MessageField
pub const WATERMARK_FIELD: &'static MessageField
Sourceimpl CheckpointItem
impl CheckpointItem
pub fn path_builder() -> CheckpointItemFieldPathBuilder
Sourceimpl CheckpointItem
impl CheckpointItem
pub const fn const_default() -> Self
Sourcepub fn checkpoint(&self) -> &Checkpoint
pub fn checkpoint(&self) -> &Checkpoint
Returns the value of checkpoint, or the default value if checkpoint is unset.
Sourcepub fn checkpoint_opt_mut(&mut self) -> Option<&mut Checkpoint>
pub fn checkpoint_opt_mut(&mut self) -> Option<&mut Checkpoint>
Sourcepub fn checkpoint_mut(&mut self) -> &mut Checkpoint
pub fn checkpoint_mut(&mut self) -> &mut Checkpoint
Returns a mutable reference to checkpoint.
If the field is unset, it is first initialized with the default value.
Sourcepub fn checkpoint_opt(&self) -> Option<&Checkpoint>
pub fn checkpoint_opt(&self) -> Option<&Checkpoint>
Sourcepub fn set_checkpoint<T: Into<Checkpoint>>(&mut self, field: T)
pub fn set_checkpoint<T: Into<Checkpoint>>(&mut self, field: T)
Sets checkpoint with the provided value.
Sourcepub fn with_checkpoint<T: Into<Checkpoint>>(self, field: T) -> Self
pub fn with_checkpoint<T: Into<Checkpoint>>(self, field: T) -> Self
Sets checkpoint with the provided value.
Sourcepub fn watermark(&self) -> &Watermark
pub fn watermark(&self) -> &Watermark
Returns the value of watermark, or the default value if watermark is unset.
Sourcepub fn watermark_opt_mut(&mut self) -> Option<&mut Watermark>
pub fn watermark_opt_mut(&mut self) -> Option<&mut Watermark>
Sourcepub fn watermark_mut(&mut self) -> &mut Watermark
pub fn watermark_mut(&mut self) -> &mut Watermark
Returns a mutable reference to watermark.
If the field is unset, it is first initialized with the default value.
Sourcepub fn watermark_opt(&self) -> Option<&Watermark>
pub fn watermark_opt(&self) -> Option<&Watermark>
Sourcepub fn set_watermark<T: Into<Watermark>>(&mut self, field: T)
pub fn set_watermark<T: Into<Watermark>>(&mut self, field: T)
Sets watermark with the provided value.
Sourcepub fn with_watermark<T: Into<Watermark>>(self, field: T) -> Self
pub fn with_watermark<T: Into<Watermark>>(self, field: T) -> Self
Sets watermark with the provided value.