EventPredicate

Struct EventPredicate 

#[non_exhaustive]
pub struct EventPredicate { pub predicate: Option<Predicate>, }
Available on crate feature unstable only.
One event-index predicate.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
predicate: Option<Predicate>

Implementations

Source

impl EventPredicate

Source

impl EventPredicate

pub fn path_builder() -> EventPredicateFieldPathBuilder

Source

impl EventPredicate

pub const fn const_default() -> Self

pub fn sender(&self) -> &SenderFilter

Returns the value of sender, or the default value if sender is unset.

pub fn sender_opt(&self) -> Option<&SenderFilter>

If sender is set, returns Some with the value; otherwise returns None.

pub fn sender_opt_mut(&mut self) -> Option<&mut SenderFilter>

If sender is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn sender_mut(&mut self) -> &mut SenderFilter

Returns a mutable reference to sender. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_sender<T: Into<SenderFilter>>(&mut self, field: T)

Sets sender with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_sender<T: Into<SenderFilter>>(self, field: T) -> Self

Sets sender with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn emit_module(&self) -> &EmitModuleFilter

Returns the value of emit_module, or the default value if emit_module is unset.

pub fn emit_module_opt(&self) -> Option<&EmitModuleFilter>

If emit_module is set, returns Some with the value; otherwise returns None.

pub fn emit_module_opt_mut(&mut self) -> Option<&mut EmitModuleFilter>

If emit_module is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn emit_module_mut(&mut self) -> &mut EmitModuleFilter

Returns a mutable reference to emit_module. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_emit_module<T: Into<EmitModuleFilter>>(&mut self, field: T)

Sets emit_module with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_emit_module<T: Into<EmitModuleFilter>>(self, field: T) -> Self

Sets emit_module with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn event_type(&self) -> &EventTypeFilter

Returns the value of event_type, or the default value if event_type is unset.

pub fn event_type_opt(&self) -> Option<&EventTypeFilter>

If event_type is set, returns Some with the value; otherwise returns None.

pub fn event_type_opt_mut(&mut self) -> Option<&mut EventTypeFilter>

If event_type is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn event_type_mut(&mut self) -> &mut EventTypeFilter

Returns a mutable reference to event_type. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_event_type<T: Into<EventTypeFilter>>(&mut self, field: T)

Sets event_type with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_event_type<T: Into<EventTypeFilter>>(self, field: T) -> Self

Sets event_type with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn event_stream_head(&self) -> &EventStreamHeadFilter

Returns the value of event_stream_head, or the default value if event_stream_head is unset.

pub fn event_stream_head_opt(&self) -> Option<&EventStreamHeadFilter>

If event_stream_head is set, returns Some with the value; otherwise returns None.

pub fn event_stream_head_opt_mut( &mut self, ) -> Option<&mut EventStreamHeadFilter>

If event_stream_head is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn event_stream_head_mut(&mut self) -> &mut EventStreamHeadFilter

Returns a mutable reference to event_stream_head. If the field is unset, it is first initialized with the default value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn set_event_stream_head<T: Into<EventStreamHeadFilter>>( &mut self, field: T, )

Sets event_stream_head with the provided value. If any other oneof field in the same oneof is set, it will be cleared.

pub fn with_event_stream_head<T: Into<EventStreamHeadFilter>>( self, field: T, ) -> Self

Sets event_stream_head with the provided value. If any other oneof field in the same oneof is set, it will be cleared.