#[non_exhaustive]pub struct GetCheckpointObjectProofRequest {
pub object_id: Option<String>,
pub checkpoint: Option<u64>,
}Available on crate feature
unstable only.Expand description
Request for a GetCheckpointObjectProof call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.object_id: Option<String>Required. The object id to prove a checkpoint outcome for (hex-encoded address).
checkpoint: Option<u64>Required. The checkpoint sequence number to query.
Implementations
Sourceimpl GetCheckpointObjectProofRequest
impl GetCheckpointObjectProofRequest
pub const OBJECT_ID_FIELD: &'static MessageField
pub const CHECKPOINT_FIELD: &'static MessageField
Sourceimpl GetCheckpointObjectProofRequest
impl GetCheckpointObjectProofRequest
pub fn path_builder() -> GetCheckpointObjectProofRequestFieldPathBuilder
Sourceimpl GetCheckpointObjectProofRequest
impl GetCheckpointObjectProofRequest
pub const fn const_default() -> Self
Sourcepub fn object_id_opt_mut(&mut self) -> Option<&mut String>
pub fn object_id_opt_mut(&mut self) -> Option<&mut String>
Sourcepub fn object_id_mut(&mut self) -> &mut String
pub fn object_id_mut(&mut self) -> &mut String
Returns a mutable reference to object_id.
If the field is unset, it is first initialized with the default value.
Sourcepub fn object_id_opt(&self) -> Option<&str>
pub fn object_id_opt(&self) -> Option<&str>
Sourcepub fn set_object_id<T: Into<String>>(&mut self, field: T)
pub fn set_object_id<T: Into<String>>(&mut self, field: T)
Sets object_id with the provided value.
Sourcepub fn with_object_id<T: Into<String>>(self, field: T) -> Self
pub fn with_object_id<T: Into<String>>(self, field: T) -> Self
Sets object_id with the provided value.
Sourcepub fn checkpoint_opt_mut(&mut self) -> Option<&mut u64>
pub fn checkpoint_opt_mut(&mut self) -> Option<&mut u64>
Sourcepub fn checkpoint_mut(&mut self) -> &mut u64
pub fn checkpoint_mut(&mut self) -> &mut u64
Returns a mutable reference to checkpoint.
If the field is unset, it is first initialized with the default value.
Sourcepub fn checkpoint_opt(&self) -> Option<u64>
pub fn checkpoint_opt(&self) -> Option<u64>
Sourcepub fn set_checkpoint(&mut self, field: u64)
pub fn set_checkpoint(&mut self, field: u64)
Sets checkpoint with the provided value.
Sourcepub fn with_checkpoint(self, field: u64) -> Self
pub fn with_checkpoint(self, field: u64) -> Self
Sets checkpoint with the provided value.