#[non_exhaustive]pub struct GetCheckpointObjectProofResponse {
pub checkpoint_summary: Option<Bytes>,
pub proof: Option<Proof>,
}unstable only.Expand description
Response containing a checkpoint-object proof and the materials needed to verify it end-to-end.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.checkpoint_summary: Option<Bytes>BCS-encoded CertifiedCheckpointSummary for the requested
checkpoint, carrying the checkpoint_artifacts_digest that the
proof’s tree_root must reconstruct, plus the BLS aggregate
signature attesting to it.
proof: Option<Proof>The proof itself: either an inclusion or a non-inclusion proof.
Implementations
Sourceimpl GetCheckpointObjectProofResponse
impl GetCheckpointObjectProofResponse
pub const CHECKPOINT_SUMMARY_FIELD: &'static MessageField
pub const INCLUSION_FIELD: &'static MessageField
pub const NON_INCLUSION_FIELD: &'static MessageField
Sourceimpl GetCheckpointObjectProofResponse
impl GetCheckpointObjectProofResponse
pub fn path_builder() -> GetCheckpointObjectProofResponseFieldPathBuilder
Sourceimpl GetCheckpointObjectProofResponse
impl GetCheckpointObjectProofResponse
pub const fn const_default() -> Self
Sourcepub fn checkpoint_summary_opt(&self) -> Option<&[u8]>
pub fn checkpoint_summary_opt(&self) -> Option<&[u8]>
Sourcepub fn set_checkpoint_summary<T: Into<Bytes>>(&mut self, field: T)
pub fn set_checkpoint_summary<T: Into<Bytes>>(&mut self, field: T)
Sets checkpoint_summary with the provided value.
Sourcepub fn with_checkpoint_summary<T: Into<Bytes>>(self, field: T) -> Self
pub fn with_checkpoint_summary<T: Into<Bytes>>(self, field: T) -> Self
Sets checkpoint_summary with the provided value.
Sourcepub fn inclusion(&self) -> &OcsInclusionProof
pub fn inclusion(&self) -> &OcsInclusionProof
Returns the value of inclusion, or the default value if inclusion is unset.
Sourcepub fn inclusion_opt(&self) -> Option<&OcsInclusionProof>
pub fn inclusion_opt(&self) -> Option<&OcsInclusionProof>
Sourcepub fn inclusion_opt_mut(&mut self) -> Option<&mut OcsInclusionProof>
pub fn inclusion_opt_mut(&mut self) -> Option<&mut OcsInclusionProof>
Sourcepub fn inclusion_mut(&mut self) -> &mut OcsInclusionProof
pub fn inclusion_mut(&mut self) -> &mut OcsInclusionProof
Returns a mutable reference to inclusion.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_inclusion<T: Into<OcsInclusionProof>>(&mut self, field: T)
pub fn set_inclusion<T: Into<OcsInclusionProof>>(&mut self, field: T)
Sets inclusion with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_inclusion<T: Into<OcsInclusionProof>>(self, field: T) -> Self
pub fn with_inclusion<T: Into<OcsInclusionProof>>(self, field: T) -> Self
Sets inclusion with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn non_inclusion(&self) -> &OcsNonInclusionProof
pub fn non_inclusion(&self) -> &OcsNonInclusionProof
Returns the value of non_inclusion, or the default value if non_inclusion is unset.
Sourcepub fn non_inclusion_opt(&self) -> Option<&OcsNonInclusionProof>
pub fn non_inclusion_opt(&self) -> Option<&OcsNonInclusionProof>
Sourcepub fn non_inclusion_opt_mut(&mut self) -> Option<&mut OcsNonInclusionProof>
pub fn non_inclusion_opt_mut(&mut self) -> Option<&mut OcsNonInclusionProof>
Sourcepub fn non_inclusion_mut(&mut self) -> &mut OcsNonInclusionProof
pub fn non_inclusion_mut(&mut self) -> &mut OcsNonInclusionProof
Returns a mutable reference to non_inclusion.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_non_inclusion<T: Into<OcsNonInclusionProof>>(&mut self, field: T)
pub fn set_non_inclusion<T: Into<OcsNonInclusionProof>>(&mut self, field: T)
Sets non_inclusion with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_non_inclusion<T: Into<OcsNonInclusionProof>>(self, field: T) -> Self
pub fn with_non_inclusion<T: Into<OcsNonInclusionProof>>(self, field: T) -> Self
Sets non_inclusion with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourceimpl GetCheckpointObjectProofResponse
impl GetCheckpointObjectProofResponse
Sourcepub fn checkpoint_summary(&self) -> &[u8] ⓘ
pub fn checkpoint_summary(&self) -> &[u8] ⓘ
Returns the value of checkpoint_summary, or the default value if checkpoint_summary is unset.