#[non_exhaustive]pub struct ListTransactionsResponse {
pub response: Option<Response>,
}unstable only.Expand description
Response message for LedgerService.ListTransactions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.response: Option<Response>Implementations
Sourceimpl ListTransactionsResponse
impl ListTransactionsResponse
pub const ITEM_FIELD: &'static MessageField
pub const WATERMARK_FIELD: &'static MessageField
pub const END_FIELD: &'static MessageField
Sourceimpl ListTransactionsResponse
impl ListTransactionsResponse
pub fn path_builder() -> ListTransactionsResponseFieldPathBuilder
Sourceimpl ListTransactionsResponse
impl ListTransactionsResponse
pub const fn const_default() -> Self
Sourcepub fn item(&self) -> &TransactionItem
pub fn item(&self) -> &TransactionItem
Returns the value of item, or the default value if item is unset.
Sourcepub fn item_opt(&self) -> Option<&TransactionItem>
pub fn item_opt(&self) -> Option<&TransactionItem>
Sourcepub fn item_opt_mut(&mut self) -> Option<&mut TransactionItem>
pub fn item_opt_mut(&mut self) -> Option<&mut TransactionItem>
Sourcepub fn item_mut(&mut self) -> &mut TransactionItem
pub fn item_mut(&mut self) -> &mut TransactionItem
Returns a mutable reference to item.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_item<T: Into<TransactionItem>>(&mut self, field: T)
pub fn set_item<T: Into<TransactionItem>>(&mut self, field: T)
Sets item with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_item<T: Into<TransactionItem>>(self, field: T) -> Self
pub fn with_item<T: Into<TransactionItem>>(self, field: T) -> Self
Sets item with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn watermark(&self) -> &Watermark
pub fn watermark(&self) -> &Watermark
Returns the value of watermark, or the default value if watermark is unset.
Sourcepub fn watermark_opt(&self) -> Option<&Watermark>
pub fn watermark_opt(&self) -> Option<&Watermark>
Sourcepub fn watermark_opt_mut(&mut self) -> Option<&mut Watermark>
pub fn watermark_opt_mut(&mut self) -> Option<&mut Watermark>
Sourcepub fn watermark_mut(&mut self) -> &mut Watermark
pub fn watermark_mut(&mut self) -> &mut Watermark
Returns a mutable reference to watermark.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_watermark<T: Into<Watermark>>(&mut self, field: T)
pub fn set_watermark<T: Into<Watermark>>(&mut self, field: T)
Sets watermark with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_watermark<T: Into<Watermark>>(self, field: T) -> Self
pub fn with_watermark<T: Into<Watermark>>(self, field: T) -> Self
Sets watermark with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn end_opt_mut(&mut self) -> Option<&mut QueryEnd>
pub fn end_opt_mut(&mut self) -> Option<&mut QueryEnd>
Sourcepub fn end_mut(&mut self) -> &mut QueryEnd
pub fn end_mut(&mut self) -> &mut QueryEnd
Returns a mutable reference to end.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.