#[non_exhaustive]pub struct MerkleNeighbourLeaf {
pub leaf: Option<ObjectReference>,
pub merkle_proof: Option<MerkleProof>,
}unstable only.Expand description
A neighbour leaf in a MerkleNonInclusionProof: an object reference
at a specific sorted position in the OCS tree, plus the inclusion
proof that authenticates it against the tree root.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.leaf: Option<ObjectReference>The object reference stored at this leaf.
merkle_proof: Option<MerkleProof>Inclusion proof for leaf at its position in the tree.
Implementations
Sourceimpl MerkleNeighbourLeaf
impl MerkleNeighbourLeaf
pub const LEAF_FIELD: &'static MessageField
pub const MERKLE_PROOF_FIELD: &'static MessageField
Sourceimpl MerkleNeighbourLeaf
impl MerkleNeighbourLeaf
pub fn path_builder() -> MerkleNeighbourLeafFieldPathBuilder
Sourceimpl MerkleNeighbourLeaf
impl MerkleNeighbourLeaf
pub const fn const_default() -> Self
Sourcepub fn leaf(&self) -> &ObjectReference
pub fn leaf(&self) -> &ObjectReference
Returns the value of leaf, or the default value if leaf is unset.
Sourcepub fn leaf_opt_mut(&mut self) -> Option<&mut ObjectReference>
pub fn leaf_opt_mut(&mut self) -> Option<&mut ObjectReference>
Sourcepub fn leaf_mut(&mut self) -> &mut ObjectReference
pub fn leaf_mut(&mut self) -> &mut ObjectReference
Returns a mutable reference to leaf.
If the field is unset, it is first initialized with the default value.
Sourcepub fn leaf_opt(&self) -> Option<&ObjectReference>
pub fn leaf_opt(&self) -> Option<&ObjectReference>
Sourcepub fn set_leaf<T: Into<ObjectReference>>(&mut self, field: T)
pub fn set_leaf<T: Into<ObjectReference>>(&mut self, field: T)
Sets leaf with the provided value.
Sourcepub fn with_leaf<T: Into<ObjectReference>>(self, field: T) -> Self
pub fn with_leaf<T: Into<ObjectReference>>(self, field: T) -> Self
Sets leaf with the provided value.
Sourcepub fn merkle_proof(&self) -> &MerkleProof
pub fn merkle_proof(&self) -> &MerkleProof
Returns the value of merkle_proof, or the default value if merkle_proof is unset.
Sourcepub fn merkle_proof_opt_mut(&mut self) -> Option<&mut MerkleProof>
pub fn merkle_proof_opt_mut(&mut self) -> Option<&mut MerkleProof>
Sourcepub fn merkle_proof_mut(&mut self) -> &mut MerkleProof
pub fn merkle_proof_mut(&mut self) -> &mut MerkleProof
Returns a mutable reference to merkle_proof.
If the field is unset, it is first initialized with the default value.
Sourcepub fn merkle_proof_opt(&self) -> Option<&MerkleProof>
pub fn merkle_proof_opt(&self) -> Option<&MerkleProof>
Sourcepub fn set_merkle_proof<T: Into<MerkleProof>>(&mut self, field: T)
pub fn set_merkle_proof<T: Into<MerkleProof>>(&mut self, field: T)
Sets merkle_proof with the provided value.
Sourcepub fn with_merkle_proof<T: Into<MerkleProof>>(self, field: T) -> Self
pub fn with_merkle_proof<T: Into<MerkleProof>>(self, field: T) -> Self
Sets merkle_proof with the provided value.