OcsNonInclusionProof

Struct OcsNonInclusionProof 

#[non_exhaustive]
pub struct OcsNonInclusionProof { pub non_inclusion_proof: Option<MerkleNonInclusionProof>, pub tree_root: Option<Bytes>, }
Available on crate feature unstable only.
An Object Checkpoint State (OCS) non-inclusion proof.

Proves that no leaf with a given object id appears in the OCS Merkle tree – i.e. that the checkpoint did not modify the object id at all. The proof’s bracketing neighbours must have object ids strictly flanking the target id, which combined with the neighbours being at adjacent indices in the sorted tree proves that no leaf with any version or digest under the target id can be in the tree.

As with OcsInclusionProof, this is anchored at the containing CheckpointSummary’s CheckpointArtifacts commitment.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
non_inclusion_proof: Option<MerkleNonInclusionProof>

Merkle non-inclusion proof over the OCS tree.

tree_root: Option<Bytes>

32-byte Merkle root of the modified-objects tree.

Implementations

Source

impl OcsNonInclusionProof

Source

impl OcsNonInclusionProof

pub fn path_builder() -> OcsNonInclusionProofFieldPathBuilder

Source

impl OcsNonInclusionProof

pub const fn const_default() -> Self

pub fn non_inclusion_proof(&self) -> &MerkleNonInclusionProof

Returns the value of non_inclusion_proof, or the default value if non_inclusion_proof is unset.

pub fn non_inclusion_proof_opt_mut( &mut self, ) -> Option<&mut MerkleNonInclusionProof>

If non_inclusion_proof is set, returns Some with a mutable reference to the value; otherwise returns None.

pub fn non_inclusion_proof_mut(&mut self) -> &mut MerkleNonInclusionProof

Returns a mutable reference to non_inclusion_proof. If the field is unset, it is first initialized with the default value.

pub fn non_inclusion_proof_opt(&self) -> Option<&MerkleNonInclusionProof>

If non_inclusion_proof is set, returns Some with the value; otherwise returns None.

pub fn set_non_inclusion_proof<T: Into<MerkleNonInclusionProof>>( &mut self, field: T, )

Sets non_inclusion_proof with the provided value.

pub fn with_non_inclusion_proof<T: Into<MerkleNonInclusionProof>>( self, field: T, ) -> Self

Sets non_inclusion_proof with the provided value.

pub fn tree_root_opt(&self) -> Option<&[u8]>

If tree_root is set, returns Some with the value; otherwise returns None.

pub fn set_tree_root<T: Into<Bytes>>(&mut self, field: T)

Sets tree_root with the provided value.

pub fn with_tree_root<T: Into<Bytes>>(self, field: T) -> Self

Sets tree_root with the provided value.

Source

impl OcsNonInclusionProof

pub fn tree_root(&self) -> &[u8]

Returns the value of tree_root, or the default value if tree_root is unset.