#[non_exhaustive]pub struct TransactionFilter {
pub terms: Vec<TransactionTerm>,
}Available on crate feature
unstable only.Expand description
DNF filter for transactions: any term may match, and each term is an AND of signed literals. An absent filter matches everything. A present filter must have at least one term, and every term must have at least one included literal.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.terms: Vec<TransactionTerm>Terms are ORed together.
Implementations
Sourceimpl TransactionFilter
impl TransactionFilter
pub const TERMS_FIELD: &'static MessageField
Sourceimpl TransactionFilter
impl TransactionFilter
pub fn path_builder() -> TransactionFilterFieldPathBuilder
Sourceimpl TransactionFilter
impl TransactionFilter
pub const fn const_default() -> Self
Sourcepub fn terms(&self) -> &[TransactionTerm]
pub fn terms(&self) -> &[TransactionTerm]
Returns the value of terms, or the default value if terms is unset.
Sourcepub fn terms_mut(&mut self) -> &mut Vec<TransactionTerm>
pub fn terms_mut(&mut self) -> &mut Vec<TransactionTerm>
Returns a mutable reference to terms.
If the field is unset, it is first initialized with the default value.
Sourcepub fn set_terms(&mut self, field: Vec<TransactionTerm>)
pub fn set_terms(&mut self, field: Vec<TransactionTerm>)
Sets terms with the provided value.
Sourcepub fn with_terms(self, field: Vec<TransactionTerm>) -> Self
pub fn with_terms(self, field: Vec<TransactionTerm>) -> Self
Sets terms with the provided value.