#[non_exhaustive]pub struct TransactionItem {
pub transaction: Option<ExecutedTransaction>,
pub watermark: Option<Watermark>,
pub transaction_offset: Option<u64>,
}unstable only.Expand description
One transaction item.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.transaction: Option<ExecutedTransaction>One matching transaction.
watermark: Option<Watermark>Progress watermark as of when this item was emitted: its cursor
is the resume point past this item, and checkpoint_hi /
checkpoint_lo (whichever matches the request ordering) is the
inclusive boundary checkpoint that the scan has fully covered.
transaction_offset: Option<u64>Zero-based position of this transaction within the checkpoint that
includes it (the checkpoint reported on the embedded
ExecutedTransaction).
Implementations
Sourceimpl TransactionItem
impl TransactionItem
pub const TRANSACTION_FIELD: &'static MessageField
pub const WATERMARK_FIELD: &'static MessageField
pub const TRANSACTION_OFFSET_FIELD: &'static MessageField
Sourceimpl TransactionItem
impl TransactionItem
pub fn path_builder() -> TransactionItemFieldPathBuilder
Sourceimpl TransactionItem
impl TransactionItem
pub const fn const_default() -> Self
Sourcepub fn transaction(&self) -> &ExecutedTransaction
pub fn transaction(&self) -> &ExecutedTransaction
Returns the value of transaction, or the default value if transaction is unset.
Sourcepub fn transaction_opt_mut(&mut self) -> Option<&mut ExecutedTransaction>
pub fn transaction_opt_mut(&mut self) -> Option<&mut ExecutedTransaction>
Sourcepub fn transaction_mut(&mut self) -> &mut ExecutedTransaction
pub fn transaction_mut(&mut self) -> &mut ExecutedTransaction
Returns a mutable reference to transaction.
If the field is unset, it is first initialized with the default value.
Sourcepub fn transaction_opt(&self) -> Option<&ExecutedTransaction>
pub fn transaction_opt(&self) -> Option<&ExecutedTransaction>
Sourcepub fn set_transaction<T: Into<ExecutedTransaction>>(&mut self, field: T)
pub fn set_transaction<T: Into<ExecutedTransaction>>(&mut self, field: T)
Sets transaction with the provided value.
Sourcepub fn with_transaction<T: Into<ExecutedTransaction>>(self, field: T) -> Self
pub fn with_transaction<T: Into<ExecutedTransaction>>(self, field: T) -> Self
Sets transaction with the provided value.
Sourcepub fn watermark(&self) -> &Watermark
pub fn watermark(&self) -> &Watermark
Returns the value of watermark, or the default value if watermark is unset.
Sourcepub fn watermark_opt_mut(&mut self) -> Option<&mut Watermark>
pub fn watermark_opt_mut(&mut self) -> Option<&mut Watermark>
Sourcepub fn watermark_mut(&mut self) -> &mut Watermark
pub fn watermark_mut(&mut self) -> &mut Watermark
Returns a mutable reference to watermark.
If the field is unset, it is first initialized with the default value.
Sourcepub fn watermark_opt(&self) -> Option<&Watermark>
pub fn watermark_opt(&self) -> Option<&Watermark>
Sourcepub fn set_watermark<T: Into<Watermark>>(&mut self, field: T)
pub fn set_watermark<T: Into<Watermark>>(&mut self, field: T)
Sets watermark with the provided value.
Sourcepub fn with_watermark<T: Into<Watermark>>(self, field: T) -> Self
pub fn with_watermark<T: Into<Watermark>>(self, field: T) -> Self
Sets watermark with the provided value.
Sourcepub fn transaction_offset_opt_mut(&mut self) -> Option<&mut u64>
pub fn transaction_offset_opt_mut(&mut self) -> Option<&mut u64>
Sourcepub fn transaction_offset_mut(&mut self) -> &mut u64
pub fn transaction_offset_mut(&mut self) -> &mut u64
Returns a mutable reference to transaction_offset.
If the field is unset, it is first initialized with the default value.
Sourcepub fn transaction_offset_opt(&self) -> Option<u64>
pub fn transaction_offset_opt(&self) -> Option<u64>
Sourcepub fn set_transaction_offset(&mut self, field: u64)
pub fn set_transaction_offset(&mut self, field: u64)
Sets transaction_offset with the provided value.
Sourcepub fn with_transaction_offset(self, field: u64) -> Self
pub fn with_transaction_offset(self, field: u64) -> Self
Sets transaction_offset with the provided value.
Sourceimpl TransactionItem
impl TransactionItem
Sourcepub fn transaction_offset(&self) -> u64
pub fn transaction_offset(&self) -> u64
Returns the value of transaction_offset, or the default value if transaction_offset is unset.