#[non_exhaustive]pub struct TransactionLiteral {
pub polarity: Option<Polarity>,
}unstable only.Expand description
One signed transaction predicate literal.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.polarity: Option<Polarity>Implementations
Sourceimpl TransactionLiteral
impl TransactionLiteral
pub const INCLUDE_FIELD: &'static MessageField
pub const EXCLUDE_FIELD: &'static MessageField
Sourceimpl TransactionLiteral
impl TransactionLiteral
pub fn path_builder() -> TransactionLiteralFieldPathBuilder
Sourceimpl TransactionLiteral
impl TransactionLiteral
pub const fn const_default() -> Self
Sourcepub fn include(&self) -> &TransactionPredicate
pub fn include(&self) -> &TransactionPredicate
Returns the value of include, or the default value if include is unset.
Sourcepub fn include_opt(&self) -> Option<&TransactionPredicate>
pub fn include_opt(&self) -> Option<&TransactionPredicate>
Sourcepub fn include_opt_mut(&mut self) -> Option<&mut TransactionPredicate>
pub fn include_opt_mut(&mut self) -> Option<&mut TransactionPredicate>
Sourcepub fn include_mut(&mut self) -> &mut TransactionPredicate
pub fn include_mut(&mut self) -> &mut TransactionPredicate
Returns a mutable reference to include.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_include<T: Into<TransactionPredicate>>(&mut self, field: T)
pub fn set_include<T: Into<TransactionPredicate>>(&mut self, field: T)
Sets include with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_include<T: Into<TransactionPredicate>>(self, field: T) -> Self
pub fn with_include<T: Into<TransactionPredicate>>(self, field: T) -> Self
Sets include with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn exclude(&self) -> &TransactionPredicate
pub fn exclude(&self) -> &TransactionPredicate
Returns the value of exclude, or the default value if exclude is unset.
Sourcepub fn exclude_opt(&self) -> Option<&TransactionPredicate>
pub fn exclude_opt(&self) -> Option<&TransactionPredicate>
Sourcepub fn exclude_opt_mut(&mut self) -> Option<&mut TransactionPredicate>
pub fn exclude_opt_mut(&mut self) -> Option<&mut TransactionPredicate>
Sourcepub fn exclude_mut(&mut self) -> &mut TransactionPredicate
pub fn exclude_mut(&mut self) -> &mut TransactionPredicate
Returns a mutable reference to exclude.
If the field is unset, it is first initialized with the default value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn set_exclude<T: Into<TransactionPredicate>>(&mut self, field: T)
pub fn set_exclude<T: Into<TransactionPredicate>>(&mut self, field: T)
Sets exclude with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.
Sourcepub fn with_exclude<T: Into<TransactionPredicate>>(self, field: T) -> Self
pub fn with_exclude<T: Into<TransactionPredicate>>(self, field: T) -> Self
Sets exclude with the provided value.
If any other oneof field in the same oneof is set, it will be cleared.