#[non_exhaustive]pub struct OcsNonInclusionProof {
pub non_inclusion_proof: Option<MerkleNonInclusionProof>,
pub tree_root: Option<Bytes>,
}unstable only.Expand description
An Object Checkpoint State (OCS) non-inclusion proof.
Proves that no leaf with a given object id appears in the OCS Merkle tree – i.e. that the checkpoint did not modify the object id at all. The proof’s bracketing neighbours must have object ids strictly flanking the target id, which combined with the neighbours being at adjacent indices in the sorted tree proves that no leaf with any version or digest under the target id can be in the tree.
As with OcsInclusionProof, this is anchored at the containing
CheckpointSummary’s CheckpointArtifacts commitment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.non_inclusion_proof: Option<MerkleNonInclusionProof>Merkle non-inclusion proof over the OCS tree.
tree_root: Option<Bytes>32-byte Merkle root of the modified-objects tree.
Implementations
Sourceimpl OcsNonInclusionProof
impl OcsNonInclusionProof
pub const NON_INCLUSION_PROOF_FIELD: &'static MessageField
pub const TREE_ROOT_FIELD: &'static MessageField
Sourceimpl OcsNonInclusionProof
impl OcsNonInclusionProof
pub fn path_builder() -> OcsNonInclusionProofFieldPathBuilder
Sourceimpl OcsNonInclusionProof
impl OcsNonInclusionProof
pub const fn const_default() -> Self
Sourcepub fn non_inclusion_proof(&self) -> &MerkleNonInclusionProof
pub fn non_inclusion_proof(&self) -> &MerkleNonInclusionProof
Returns the value of non_inclusion_proof, or the default value if non_inclusion_proof is unset.
Sourcepub fn non_inclusion_proof_opt_mut(
&mut self,
) -> Option<&mut MerkleNonInclusionProof>
pub fn non_inclusion_proof_opt_mut( &mut self, ) -> Option<&mut MerkleNonInclusionProof>
Sourcepub fn non_inclusion_proof_mut(&mut self) -> &mut MerkleNonInclusionProof
pub fn non_inclusion_proof_mut(&mut self) -> &mut MerkleNonInclusionProof
Returns a mutable reference to non_inclusion_proof.
If the field is unset, it is first initialized with the default value.
Sourcepub fn non_inclusion_proof_opt(&self) -> Option<&MerkleNonInclusionProof>
pub fn non_inclusion_proof_opt(&self) -> Option<&MerkleNonInclusionProof>
Sourcepub fn set_non_inclusion_proof<T: Into<MerkleNonInclusionProof>>(
&mut self,
field: T,
)
pub fn set_non_inclusion_proof<T: Into<MerkleNonInclusionProof>>( &mut self, field: T, )
Sets non_inclusion_proof with the provided value.
Sourcepub fn with_non_inclusion_proof<T: Into<MerkleNonInclusionProof>>(
self,
field: T,
) -> Self
pub fn with_non_inclusion_proof<T: Into<MerkleNonInclusionProof>>( self, field: T, ) -> Self
Sets non_inclusion_proof with the provided value.
Sourcepub fn tree_root_opt(&self) -> Option<&[u8]>
pub fn tree_root_opt(&self) -> Option<&[u8]>
Sourcepub fn set_tree_root<T: Into<Bytes>>(&mut self, field: T)
pub fn set_tree_root<T: Into<Bytes>>(&mut self, field: T)
Sets tree_root with the provided value.
Sourcepub fn with_tree_root<T: Into<Bytes>>(self, field: T) -> Self
pub fn with_tree_root<T: Into<Bytes>>(self, field: T) -> Self
Sets tree_root with the provided value.